@@ -586,7 +586,15 @@ def read_commands():
             command_id = filename[:-5]
             status = read_command_status(command_id)
             if status:
-                command = command_str(status.get('command', '-'), status.get('params', []))
+                cmd = status.get('command', '-')
+                params = status.get('params', [])
+                if cmd.endswith('/run-para'):
+                    cmd = "batch"
+                    index = params.index('run')
+                    if index:
+                        params = params[index+1:]
+                        params[0] = os.path.basename(params[0])
+                command = command_str(cmd, params)
                 if status.get('status') == 'running' and status.get('last_update',0)<datetime.now().timestamp()-5:
                     output_file_path = get_output_file_path(command_id)
                     if os.path.exists(output_file_path):
@@ -827,6 +835,8 @@ def run_dynamic_command(cmd):
         noprefix = exe.get("schema", {}).get("schema_options", {}).get("noprefix_params", {})
         convert_params = exe.get("schema", {}).get("schema_options", {}).get("convert_params", {})
         schema_params = exe.get("schema", {}).get("properties", {})
+        batch_param = exe.get("schema", {}).get("schema_options", {}).get("batch_param", None)
+        batch_values = []
         if isinstance(data_params, dict) and not schema_params:
             return None
         if isinstance(data_params, dict):
@@ -852,6 +862,10 @@ def run_dynamic_command(cmd):
                         params += f"{prefix} "
                     continue
                 params += f"{prefix}{separator}"
+                values = shlex.split(value) if isinstance(value, str) else value
+                if param == batch_param and len(values)>1:
+                    batch_values = values
+                    value="@1"
                 if isinstance(value, list):
                     params += " ".join(value)
                 else:
@@ -865,7 +879,7 @@ def run_dynamic_command(cmd):
             params = shlex.split(' '.join(params)) if isinstance(params, list) else []
         except Exception as e:
             return None
-        return params
+        return params, batch_values
 
     cmd_path = os.path.join(".", os.path.basename(cmd))
     if not os.path.isfile(cmd_path) or not os.access(cmd_path, os.X_OK):
@@ -874,11 +888,13 @@ def run_dynamic_command(cmd):
         data = request.json
     except Exception as e:
         data = {}
-    params = parse_params(cmd, data.get('params'))
+    params, batch_values = parse_params(cmd, data.get('params'))
     if params is None:
         return jsonify({'error': 'Invalid parameters'}), 400
     rows = data.get('rows', tty_rows) or tty_rows
     cols = data.get('cols', tty_cols) or tty_cols
+    parallel = data.get('parallel', 1)
+    delay = data.get('delay', 0)
     user = session.get('username', '-')
     command_id = str(uuid.uuid4())
     update_command_status(command_id, {
@@ -889,6 +905,10 @@ def run_dynamic_command(cmd):
         'from': request.remote_addr,
     })
     Path(get_output_file_path(command_id)).touch()
+    if batch_values:
+        params = ["-n", "-p", str(parallel), "-d", str(delay), "-P", *batch_values, '--', sys.argv[0], "-d", ".", "--", "run", cmd_path, *params]
+        cmd_path = shutil.which("run-para")
+        print(params)
     thread = threading.Thread(target=run_command, args=(request.remote_addr, user, cmd_path, params, command_id, rows, cols))
     thread.start()
     return jsonify({'message': 'Command is running', 'command_id': command_id})
@@ -1021,13 +1041,16 @@ def swagger_yaml():
                 "properties": {
                     "params": {"type": "array", "items": {"type": "string"}, "default": []},
                     "rows": {"type": "integer", "description": "tty nb rows", "default": tty_rows},
-                    "cols": {"type": "integer", "description": "tty nb columns", "default": tty_cols}
+                    "cols": {"type": "integer", "description": "tty nb columns", "default": tty_cols},
                 }
             }
             if exe["schema"]:
-                # if exec["schema"].get("schema_options"):
-                #     del exe["schema"]["schema_options"]
                 cmd_schema["properties"]["params"] = exe["schema"]
+                if exe["schema"].get("schema_options", {}).get("batch_param"):
+                  cmd_schema["properties"].update({
+                    "parallel": {"type": "integer", "description": 'nb parallel jobs', "default": 1, "required": True, "minimum": 1, "maximum": 100},
+                    "delay": {"type": "number", "description": "initial delay in s between jobs", "default": 10, "required": True, "minimum": 0, "maximum": 600},
+                  })
             swagger_spec.setdefault("paths", {})[dynamic_path] = {
                 "post": {
                     "summary": f"Run command {exe['command']}",
@@ -1038,7 +1061,7 @@ def swagger_yaml():
                     "parameters": [
                         {
                             "in": "body",
-                            "name": "reuqestBody",
+                            "name": "requestBody",
                             "schema": cmd_schema
                         }
                     ],
@@ -1062,6 +1085,40 @@ def swagger_yaml():
     except Exception as e:
         return Response(f"Error reading swagger spec: {e}", status=500)
 
+@app.route('/commands/<command_id>/run', methods=['POST'])
+def relaunch_command(command_id):
+    log_request(f"relaunch_command {command_id}")
+    status = read_command_status(command_id)
+    if not status:
+        return jsonify({'error': 'Invalid command_id'}), 404
+
+    data = request.json or {}
+    command = status['command']
+    params = status['params']
+    rows = data.get('rows', tty_rows)
+    cols = data.get('cols', tty_cols)
+
+    command_path = command
+    if not os.path.isfile(command_path) or not os.access(command_path, os.X_OK):
+        return jsonify({'error': 'Command not found or not executable'}), 400
+
+    # Get the user from the session
+    user = session.get('username', '-')
+    new_command_id = str(uuid.uuid4())
+    update_command_status(new_command_id, {
+        'status': 'running',
+        'command': command,
+        'params': params,
+        'user': user,
+        'from': request.remote_addr,
+    })
+
+    Path(get_output_file_path(new_command_id)).touch()
+    thread = threading.Thread(target=run_command, args=(request.remote_addr, user, command_path, params, new_command_id, rows, cols))
+    thread.start()
+
+    return jsonify({'message': 'Command is running', 'command_id': new_command_id})
+
 def main():
     global COMMAND_STATUS_DIR
     basef = f"{CONFDIR}/pywebexec_{args.listen}:{args.port}"
