@@ -263,8 +263,7 @@ paramsInput.addEventListener('focus', () => {
     if (paramsContainer.style.display == 'none') {
         $('#schemaForm').html('');
     }
-    if (gExecutables[currentCmd] && gExecutables[currentCmd].schema && paramsContainer.style.display == 'none') {
-        // sProp = gExecutables[currentCmd].schema.properties;
+    if (gExecutables[currentCmd] && gExecutables[currentCmd].schema && gExecutables[currentCmd].schema.properties && paramsContainer.style.display == 'none') {
         createSchemaForm($('#schemaForm'), gExecutables[currentCmd].schema, async function (errors, values) {
             if (errors) {
                 console.log(errors);
@@ -272,13 +271,20 @@ paramsInput.addEventListener('focus', () => {
                 const commandName = commandInput.value;
                 fitAddon.fit();
                 terminal.clear();
+                payload = { params: values, rows: terminal.rows, cols: terminal.cols }
+                if ('parallel' in values) {
+                    payload['parallel'] = values['parallel'];
+                    payload['delay'] = values['delay'];
+                    delete payload['params']['parallel'];
+                    delete payload['params']['delay'];
+                }
                 try {
                     const response = await fetch(`/commands/${commandName}`, {
                         method: 'POST',
                         headers: {
                             'Content-Type': 'application/json'
                         },
-                        body: JSON.stringify({ params: values, rows: terminal.rows, cols: terminal.cols })
+                        body: JSON.stringify(payload)
                     });
         
                     if (!response.ok) {
